Decryptor

Struct Decryptor 

pub struct Decryptor<C: Config<F, T>, F: PrimeField256, const T: usize, const R: usize> { /* private fields */ }
Decrypts an arbitrary number of field elements in batches of R using the Poseidon permutation with state size T.

R must be T - 1 (the last element is reserved for capacity).

This symmetric cipher is implemented using the Poseidon PRP as a block cipher in duplex sponge mode, which is similar to CFB. The key lives in the capacity element.

Implementations

Source

impl<C: Config<F, T>, F: PrimeField256, const T: usize, const R: usize> Decryptor<C, F, T, R>

pub fn new(key: F, nonce: F) -> Self

Constructs a Decryptor with the specified key and nonce.

pub fn decrypt(&mut self, block: [F; R]) -> [F; R]

Decrypts a block of R field elements.

pub fn finalize(self, checksum: F) -> Result<()>

Performs the final authentication.