pub struct Decryptor<C: Config<F, T>, F: PrimeField256, const T: usize, const R: usize> { /* private fields */ }Expand description
Decrypts an arbitrary number of field elements in batches of R using the Poseidon permutation
with state size T.
R must be T - 1 (the last element is reserved for capacity).
This symmetric cipher is implemented using the Poseidon PRP as a block cipher in duplex sponge mode, which is similar to CFB. The key lives in the capacity element.
Implementations